@@ -12,12 +12,14 @@
 # ##################################
 
 # Standard library
+import ast
 import logging
 from dataclasses import dataclass
 from functools import lru_cache
 from os import PathLike, getenv
 from os.path import expanduser, expandvars
 from pathlib import Path
+from shutil import which
 from typing import Tuple
 
 # #############################################################################
@@ -73,11 +75,36 @@ def get_qdt_working_directory(
 class OSConfiguration:
     """Settings related to QGIS and depending on operating system"""
 
+    name_python: str
+    names_alter: list = None
     profiles_path: Path = getenv("QGIS_CUSTOM_CONFIG_PATH")
+    qgis_bin_exe_path: str = None
     shortcut_extension: str = None
     shortcut_forbidden_chars: Tuple[str] = None
     shortcut_icon_extensions: Tuple[str] = None
 
+    @property
+    def get_qgis_bin_path(self) -> Path:
+        """_summary_
+
+        Returns:
+            Path: _description_
+        """
+        if getenv("QDT_QGIS_EXE_PATH"):
+            qdt_qgis_exe_path = ast.literal_eval(getenv("QDT_QGIS_EXE_PATH"))
+            if isinstance(qdt_qgis_exe_path, str):
+                return Path(expandvars(expanduser("%APPDATA%/QGIS/QGIS3/profiles")))
+            elif isinstance(qdt_qgis_exe_path, dict):
+                for k, v in qdt_qgis_exe_path:
+                    if k in self.names_alter:
+                        return v
+            else:
+                return qdt_qgis_exe_path
+        elif which("qgis"):
+            return Path(which("qgis"))
+        else:
+            return Path(expandvars(expanduser(self.qgis_bin_exe_path)))
+
     def valid_shortcut_name(self, shortcut_name: str) -> bool:
         """Check if a shortcut name is valid.
 
@@ -101,31 +128,40 @@ class OSConfiguration:
 
 OS_CONFIG: dict = {
     "darwin": OSConfiguration(
+        name_python="darwin",
+        names_alter=["apple", "mac", "macos"],
         profiles_path=Path(
             getenv(
                 "QGIS_CUSTOM_CONFIG_PATH",
                 Path.home() / "Library/Application Support/QGIS/QGIS3/profiles/",
             )
         ),
+        qgis_bin_exe_path="/usr/bin/qgis",
         shortcut_extension="app",
         shortcut_icon_extensions=("icns",),
     ),
     "linux": OSConfiguration(
+        name_python="linux",
+        names_alter=["kubuntu", "ubuntu"],
         profiles_path=Path(
             getenv(
                 "QGIS_CUSTOM_CONFIG_PATH",
                 Path.home() / ".local/share/QGIS/QGIS3/profiles/",
             )
         ),
+        qgis_bin_exe_path="/usr/bin/qgis",
         shortcut_extension=".desktop",
         shortcut_icon_extensions=("ico", "svg", "png"),
     ),
     "win32": OSConfiguration(
+        name_python="win32",
+        names_alter=["win", "windows"],
         profiles_path=Path(
             getenv(
                 "QGIS_CUSTOM_CONFIG_PATH", expandvars("%APPDATA%/QGIS/QGIS3/profiles")
             )
         ),
+        qgis_bin_exe_path="%PROGRAMFILES%/QGIS/3_22/bin/qgis-ltr-bin.exe",
         shortcut_extension=".lnk",
         shortcut_forbidden_chars=("<", ">", ":", '"', "/", "\\", "|", "?", "*"),
         shortcut_icon_extensions=("ico",),
